==> react-7.8.0.tgz: package/es/MenuItem/index.js <==
function _inheritsLoose(subClass, superClass) { subClass.prototype = Object.create(superClass.prototype); subClass.prototype.constructor = subClass; subClass.__proto__ = superClass; }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

import React from 'react';
import PropTypes from 'prop-types';
import { EventOverlay, ListItem, Icon } from "./..";

var MenuItem =
/*#__PURE__*/
function (_React$Component) {
  _inheritsLoose(MenuItem, _React$Component);

  function MenuItem() {
    var _temp, _this;

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return (_temp = _this = _React$Component.call.apply(_React$Component, [this].concat(args)) || this, _this.state = {
      anchorRef: null
    }, _this.handleKeyDown = function (e) {
      var handleKeyDown = _this.context.handleKeyDown;
      var index = _this.props.index;
      handleKeyDown && handleKeyDown(index, _assertThisInitialized(_assertThisInitialized(_this)), e);
    }, _this.handleClick = function (e) {
      var handleClick = _this.context.handleClick;
      var index = _this.props.index;
      handleClick && handleClick(index, _assertThisInitialized(_assertThisInitialized(_this)), e);
    }, _temp) || _assertThisInitialized(_this);
  }

  var _proto = MenuItem.prototype;

  _proto.render = function render() {
    var _this2 = this;

    var _this$props = this.props,
        isOpen = _this$props.isOpen,
        focus = _this$props.focus,
        isHeader = _this$props.isHeader,
        disabled = _this$props.disabled,
        value = _this$props.value,
        className = _this$props.className,
        ariaLabel = _this$props.ariaLabel,
        subMenu = _this$props.subMenu,
        selectedValue = _this$props.selectedValue,
        separator = _this$props.separator;
    return React.createElement("div", {
      className: 'cui-menu-item' + ("" + (className && " " + className || '')),
      "aria-expanded": isOpen,
      "aria-haspopup": !!subMenu
    }, React.createElement(ListItem, {
      onClick: this.handleClick,
      onKeyDown: this.handleKeyDown,
      ref: function ref(_ref) {
        return !_this2.state.anchorRef && _this2.setState({
          anchorRef: _ref
        });
      },
      focus: focus,
      disabled: disabled,
      isReadOnly: isHeader,
      active: isOpen,
      value: value,
      role: "menuitem",
      focusOnLoad: true,
      separator: separator
    }, React.createElement("div", {
      className: "cui-menu-item__content"
    }, this.props.children), React.createElement("div", {
      className: "cui-menu-item__selected-value",
      title: selectedValue
    }, subMenu && selectedValue), React.createElement("div", {
      className: "cui-menu-item__arrow"
    }, subMenu && React.createElement(Icon, {
      name: "arrow-right_16"
    }))), isOpen ? React.createElement(EventOverlay, {
      anchorNode: this.state.anchorRef,
      isOpen: isOpen,
      direction: "right-top",
      closeOnClick: false
    }, React.createElement("div", {
      "aria-label": ariaLabel,
      role: "menu"
    }, subMenu)) : null);
  };

  return MenuItem;
}(React.Component);

MenuItem.displayName = 'MenuItem';
export { MenuItem as default };
MenuItem.propTypes = {
  children: PropTypes.node,
  subMenu: PropTypes.array,
  isOpen: PropTypes.bool,
  focus: PropTypes.bool,
  isHeader: PropTypes.bool,
  disabled: PropTypes.bool,
  value: PropTypes.oneOfType([PropTypes.string, PropTypes.number, PropTypes.object, PropTypes.array]),
  selectedValue: PropTypes.string,
  className: PropTypes.string,
  shouldCloseMenu: PropTypes.bool,
  ariaLabel: PropTypes.string,
  index: PropTypes.array,
  menuItem: PropTypes.array,
  separator: PropTypes.bool
};
MenuItem.contextTypes = {
  handleClick: PropTypes.func,
  handleKeyDown: PropTypes.func
};
MenuItem.defaultProps = {
  children: null,
  subMenu: null,
  isOpen: false,
  focus: false,
  isHeader: false,
  disabled: false,
  value: '',
  className: '',
  shouldCloseMenu: false,
  ariaLabel: '',
  selectedValue: '',
  separator: false
};

==> react-7.10.0.tgz: package/es/MenuItem/index.js <==
function _inheritsLoose(subClass, superClass) { subClass.prototype = Object.create(superClass.prototype); subClass.prototype.constructor = subClass; subClass.__proto__ = superClass; }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

import React from 'react';
import PropTypes from 'prop-types';
import { EventOverlay, ListItem, Icon } from "./..";

var MenuItem =
/*#__PURE__*/
function (_React$Component) {
  _inheritsLoose(MenuItem, _React$Component);

  function MenuItem() {
    var _temp, _this;

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return (_temp = _this = _React$Component.call.apply(_React$Component, [this].concat(args)) || this, _this.state = {
      anchorRef: null
    }, _this.handleKeyDown = function (e) {
      var handleKeyDown = _this.context.handleKeyDown;
      var index = _this.props.index;
      handleKeyDown && handleKeyDown(index, _assertThisInitialized(_assertThisInitialized(_this)), e);
    }, _this.handleClick = function (e) {
      var handleClick = _this.context.handleClick;
      var index = _this.props.index;
      handleClick && handleClick(index, _assertThisInitialized(_assertThisInitialized(_this)), e);
    }, _temp) || _assertThisInitialized(_this);
  }

  var _proto = MenuItem.prototype;

  _proto.render = function render() {
    var _this2 = this;

    var _this$props = this.props,
        ariaLabel = _this$props.ariaLabel,
        className = _this$props.className,
        disabled = _this$props.disabled,
        focus = _this$props.focus,
        isHeader = _this$props.isHeader,
        isOpen = _this$props.isOpen,
        selectedValue = _this$props.selectedValue,
        separator = _this$props.separator,
        subMenu = _this$props.subMenu,
        title = _this$props.title,
        value = _this$props.value;
    return React.createElement("div", {
      className: 'cui-menu-item' + ("" + (className && " " + className || '')),
      "aria-expanded": isOpen,
      "aria-haspopup": !!subMenu
    }, React.createElement(ListItem, {
      active: isOpen,
      disabled: disabled,
      focus: focus,
      focusOnLoad: true,
      isReadOnly: isHeader,
      onClick: this.handleClick,
      onKeyDown: this.handleKeyDown,
      ref: function ref(_ref) {
        return !_this2.state.anchorRef && _this2.setState({
          anchorRef: _ref
        });
      },
      role: "menuitem",
      separator: separator,
      title: title,
      value: value
    }, React.createElement("div", {
      className: "cui-menu-item__content"
    }, this.props.children), React.createElement("div", {
      className: "cui-menu-item__selected-value",
      title: selectedValue
    }, subMenu && selectedValue), React.createElement("div", {
      className: "cui-menu-item__arrow"
    }, subMenu && React.createElement(Icon, {
      name: "arrow-right_16"
    }))), isOpen ? React.createElement(EventOverlay, {
      anchorNode: this.state.anchorRef,
      isOpen: isOpen,
      direction: "right-top",
      closeOnClick: false
    }, React.createElement("div", {
      "aria-label": ariaLabel,
      role: "menu"
    }, subMenu)) : null);
  };

  return MenuItem;
}(React.Component);

MenuItem.displayName = 'MenuItem';
export { MenuItem as default };
MenuItem.contextTypes = {
  handleClick: PropTypes.func,
  handleKeyDown: PropTypes.func
};
MenuItem.propTypes = {
  ariaLabel: PropTypes.string,
  children: PropTypes.node,
  className: PropTypes.string,
  disabled: PropTypes.bool,
  index: PropTypes.array,
  isHeader: PropTypes.bool,
  isOpen: PropTypes.bool,
  focus: PropTypes.bool,
  menuItem: PropTypes.array,
  selectedValue: PropTypes.string,
  separator: PropTypes.bool,
  shouldCloseMenu: PropTypes.bool,
  subMenu: PropTypes.array,
  title: PropTypes.string,
  value: PropTypes.oneOfType([PropTypes.string, PropTypes.number, PropTypes.object, PropTypes.array])
};
MenuItem.defaultProps = {
  ariaLabel: '',
  className: '',
  children: null,
  disabled: false,
  focus: false,
  isHeader: false,
  isOpen: false,
  selectedValue: '',
  separator: false,
  shouldCloseMenu: false,
  subMenu: null,
  title: '',
  value: ''
};
